@@ -127,6 +127,7 @@ main (int argc, char **argv)
 
   GC_INIT ();
   set_program_name (argv[0]);
+  estr_init ();
 
   /* Set up Lisp environment now so it's available to files and
      expressions specified on the command-line. */
@@ -137,7 +138,7 @@ main (int argc, char **argv)
   opterr = 0; /* Don't display errors for unknown options */
   for (;;)
     {
-      int this_optind = optind ? optind : 1, longindex, c;
+      int this_optind = optind ? optind : 1, longindex = -1, c;
       char *buf, *shortopt;
 
       /* Leading `-' means process all arguments in order, treating
